@@ -19,13 +19,13 @@ from pathlib import Path
 from typing import Any, Dict, List, Optional, Set
 
 from dateutil.parser import parse
-from jsonschema import validate  # type: ignore
+from jsonschema import validate
 from rp2.abstract_country import AbstractCountry
 from rp2.configuration_schema import CONFIGURATION_SCHEMA
 from rp2.rp2_decimal import ZERO, RP2Decimal
 from rp2.rp2_error import RP2TypeError, RP2ValueError
 
-VERSION: str = "0.9.6"
+VERSION: str = "0.9.7"
 MAX_YEAR: int = sys.maxsize
 
 
